@@ -340,7 +340,7 @@ impl Socket {
                                 break;
                             }
                         }
-                        tokio::time::sleep(tokio::time::Duration::from_millis(1000)).await;
+                        tokio::time::sleep(tokio::time::Duration::from_millis(3000)).await;
                     }
 
                     let res = close_recv.recv().await;
@@ -349,7 +349,7 @@ impl Socket {
                         // println!("{}", code);
                         // if code == 0 {
                         app_send.send(Msg::Close(1000)).await;
-                        ws_send.send(Msg::Clear()).await;
+                        ws_send.send(Msg::Close(1000)).await;
                         // }
                         // else if code == 1 {
                         //     break
